Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Timestream.

Actions, resources, and condition keys for Amazon Timestream - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Timestream

Amazon Timestream (service prefix: `timestream` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by Amazon Timestream
- Resource types defined by Amazon Timestream
- Condition keys for Amazon Timestream

## Actions defined by Amazon Timestream

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CancelQuery | Grants permission to cancel queries in your account | Write |  |  | timestream:DescribeEndpoints
CreateBatchLoadTask | Grants permission to create a batch load task in your account | Write | table* |  | timestream:DescribeEndpoints timestream:WriteRecords
CreateDatabase | Grants permission to create a database in your account | Write | database* |  | timestream:DescribeEndpoints
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateScheduledQuery | Grants permission to create a scheduled query in your account | Write |  | aws:RequestTag/${TagKey} aws:TagKeys | iam:PassRole timestream:DescribeEndpoints
CreateTable | Grants permission to create a table in your account | Write | table* |  | timestream:DescribeEndpoints
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteDatabase | Grants permission to delete a database in your account | Write | database* |  | timestream:DescribeEndpoints
DeleteScheduledQuery | Grants permission to delete a scheduled query in your account | Write | scheduled-query* |  | timestream:DescribeEndpoints
DeleteTable | Grants permission to delete a table in your account | Write | table* |  | timestream:DescribeEndpoints
DescribeBatchLoadTask | Grants permission to describe a batch load task in your account | Read |  |  | timestream:DescribeEndpoints
DescribeDatabase | Grants permission to describe a database in your account | Read | database* |  | timestream:DescribeEndpoints
DescribeEndpoints | Grants permission to describe timestream endpoints | List |  |  |
DescribeScheduledQuery | Grants permission to describe a scheduled query in your account | Read | scheduled-query* |  | timestream:DescribeEndpoints
DescribeTable | Grants permission to describe a table in your account | Read | table* |  | timestream:DescribeEndpoints
ExecuteScheduledQuery | Grants permission to execute a scheduled query in your account | Write | scheduled-query* |  | timestream:DescribeEndpoints
GetAwsBackupStatus | Grants permission to get Status of a Timestream Table Backup | Read |  |  | timestream:DescribeEndpoints
GetAwsRestoreStatus | Grants permission to get Status of a Timestream Table Restore | Read |  |  | timestream:DescribeEndpoints
ListBatchLoadTasks | Grants permission to list batch load tasks in your account | List |  |  | timestream:DescribeEndpoints
ListDatabases | Grants permission to list databases in your account | List |  |  | timestream:DescribeEndpoints
ListMeasures | Grants permission to list measures of a table in your account | List | table* |  | timestream:DescribeEndpoints
ListScheduledQueries | Grants permission to list scheduled queries in your account | List |  |  | timestream:DescribeEndpoints
ListTables | Grants permission to list tables in your account | List | database* |  | timestream:DescribeEndpoints
ListTagsForResource | Grants permission to list tags of a resource in your account | Read | database* |  | timestream:DescribeEndpoints
scheduled-query* |  |
table* |  |
PrepareQuery | Grants permission to issue prepare queries | Read | table* |  | timestream:DescribeEndpoints timestream:Select
ResumeBatchLoadTask | Grants permission to resume a batch load task in your account | Write |  |  | timestream:DescribeEndpoints timestream:WriteRecords
Select | Grants permission to issue 'select from table' queries | Read | table* |  | timestream:DescribeEndpoints
SelectValues | Grants permission to issue 'select 1' queries | Read |  |  | timestream:DescribeEndpoints
StartAwsBackupJob | Grants permission to start a Backup Job for a Timestream Table | Write | table* |  | timestream:DescribeEndpoints
StartAwsRestoreJob | Grants permission to start Restore Job for a Backup of Timestream Table | Write | table* |  | timestream:DescribeEndpoints
TagResource | Grants permission to add tags to a resource | Tagging | database* |  | timestream:DescribeEndpoints
scheduled-query* |  |
table* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
Unload | Grants permission to issue Unload queries | Write | table* |  | s3:AbortMultipartUpload s3:GetObject s3:PutObject timestream:DescribeEndpoints timestream:Select
UntagResource | Grants permission to remove a tag from a resource | Tagging | database* |  | timestream:DescribeEndpoints
scheduled-query* |  |
table* |  |
| aws:TagKeys |
UpdateDatabase | Grants permission to update a database in your account | Write | database* |  | timestream:DescribeEndpoints
UpdateScheduledQuery | Grants permission to update a scheduled query in your account | Write | scheduled-query* |  | timestream:DescribeEndpoints
UpdateTable | Grants permission to update a table in your account | Write | table* |  | timestream:DescribeEndpoints
WriteRecords | Grants permission to ingest data to a table in your account | Write | table* |  | timestream:DescribeEndpoints

## Resource types defined by Amazon Timestream

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
database | `arn:$ { Partition}:timestream:$ { Region}:$ { Account}:database/$ { DatabaseName}` | aws:ResourceTag/${TagKey}
table | `arn:$ { Partition}:timestream:$ { Region}:$ { Account}:database/$ { DatabaseName}/table/$ { TableName}` | aws:ResourceTag/${TagKey}
scheduled-query | `arn:$ { Partition}:timestream:$ { Region}:$ { Account}:scheduled-query/$ { ScheduledQueryName}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon Timestream

Amazon Timestream defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters access by tag key-value pairs attached to the resource | String
aws:TagKeys | Filters access by the presence of tag keys in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.